/*
 * Copyright 2006-2020 The MZmine Development Team
 * 
 * This file is part of MZmine.
 * 
 * MZmine is free software; you can redistribute it and/or modify it under the terms of the GNU
 * General Public License as published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 * 
 * MZmine is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with MZmine; if not,
 * write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
 * USA
 */

/*
 * This module was prepared by Abi Sarvepalli, Christopher Jensen, and Zheng Zhang at the Dorrestein
 * Lab (University of California, San Diego).
 * 
 * It is freely available under the GNU GPL licence of MZmine2.
 * 
 * For any questions or concerns, please refer to:
 * https://groups.google.com/forum/#!forum/molecular_networking_bug_reports
 * 
 * Credit to the Du-Lab development team for the initial commitment to the MGF export module.
 */

package io.github.mzmine.modules.io.spectraldbsubmit.param;

import io.github.mzmine.parameters.Parameter;
import io.github.mzmine.parameters.impl.SimpleParameterSet;
import io.github.mzmine.parameters.parametertypes.DoubleParameter;
import io.github.mzmine.parameters.parametertypes.IntegerParameter;
import io.github.mzmine.parameters.parametertypes.ParameterSetParameter;
import io.github.mzmine.parameters.parametertypes.StringParameter;

/**
 * 
 * @author Robin Schmid (robinschmid@uni-muenster.de)
 *
 */
public class LibrarySubmitIonParameters extends SimpleParameterSet {

  public static final ParameterSetParameter META_PARAM =
      new ParameterSetParameter("Metadata", "", new LibraryMetaDataParameters());
  public static final ParameterSetParameter SUBMIT_PARAM =
      new ParameterSetParameter("Submit", "", new LibrarySubmitParameters());
  // set later
  public static final StringParameter ADDUCT = new StringParameter("ADDUCT", "", "", false);
  public static final DoubleParameter MZ = new DoubleParameter("MZ", "");
  public static final IntegerParameter CHARGE = new IntegerParameter("CHARGE", "", 0);

  public LibrarySubmitIonParameters() {
    super(new Parameter[] {
        // meta data param
        META_PARAM,
        // submit param
        SUBMIT_PARAM,
        // Ion specific
        ADDUCT, MZ, CHARGE});
  }
}
