/*
 *  Copyright 2006-2020 The MZmine Development Team
 *
 *  This file is part of MZmine.
 *
 *  MZmine is free software; you can redistribute it and/or modify it under the terms of the GNU
 *  General Public License as published by the Free Software Foundation; either version 2 of the
 *  License, or (at your option) any later version.
 *
 *  MZmine is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 *  the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 *  Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with MZmine; if not,
 *  write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
 *  USA
 */

package io.github.mzmine.modules.visualization.imsfeaturevisualizer;

import io.github.mzmine.datamodel.features.ModularFeature;
import io.github.mzmine.main.MZmineCore;
import io.github.mzmine.modules.MZmineModule;
import io.github.mzmine.parameters.ParameterSet;
import java.util.Collection;
import javafx.application.Platform;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;

public class IMSFeatureVisualizerModule implements MZmineModule {

  public static final String NAME = "Ion mobility feature visualizer";

  public static void visualizeFeaturesInNewTab(Collection<ModularFeature> features,
      boolean useMobilograms) {
    if (!Platform.isFxApplicationThread()) {
      Platform.runLater(() -> MZmineCore.getDesktop()
          .addTab(new IMSFeatureVisualizerTab(features, useMobilograms)));
    } else {
      MZmineCore.getDesktop().addTab(new IMSFeatureVisualizerTab(features, useMobilograms));
    }
  }

  @Nonnull
  @Override
  public String getName() {
    return NAME;
  }

  @Nullable
  @Override
  public Class<? extends ParameterSet> getParameterSetClass() {
    return IMSFeatureVisualizerParameters.class;
  }
}
